@@ -11,7 +11,7 @@ pub struct RestApiClientBuilder
     api_base_url: Result<Url, reqwest::Error>,
     before_request_handler: Option< Pin<Arc< dyn Fn(String) -> Pin<Box< dyn Future<Output = ()> + Send >> + Send + Sync >> >,
     after_request_handler: Option< Pin<Arc< dyn Fn(&HeaderMap) -> Pin<Box< dyn Future<Output = ()> + Send >> + Send + Sync >> >,
-    handle_api_error: Option< Arc<dyn Fn(StatusCode, Option<String>) -> ApiError> >
+    handle_api_error: Option< Arc<dyn Fn(StatusCode, Option<String>) -> ApiError + Send + Sync> >
 }
 impl RestApiClientBuilder {
     pub fn new<T: IntoUrl>(http_client: reqwest::Client, api_base_url: T) -> Self {
@@ -25,7 +25,7 @@ impl RestApiClientBuilder {
     }
     pub fn on_api_error<Func>(mut self, handler: Func) -> Self
     where
-        Func: Fn(StatusCode, Option<String>) -> ApiError + 'static
+        Func: Fn(StatusCode, Option<String>) -> ApiError + Send + Sync + 'static
     {
         self.handle_api_error = Some(Arc::new( handler));
         self
@@ -66,7 +66,7 @@ pub struct RestApiClient
     api_base_url: String,
     before_request_handler: Option< Pin<Arc< dyn Fn(String) -> Pin<Box< dyn Future<Output = ()> + Send >> + Send + Sync >> >,
     after_request_handler: Option< Pin<Arc< dyn Fn(&HeaderMap) -> Pin<Box< dyn Future<Output = ()> + Send >> + Send + Sync >> >,
-    handle_api_error: Option< Arc<dyn Fn(StatusCode, Option<String>) -> ApiError> >
+    handle_api_error: Option< Arc<dyn Fn(StatusCode, Option<String>) -> ApiError + Send + Sync> >
 }
 impl RestApiClient
 {
